@@ -207,7 +207,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		Ok(deserialize(&buf)?)
 	} // }}}
 
-	#[instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display()))]
+	#[cfg_attr(feature = "full-instrumentation", instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display())))]
 	async fn get_index_entry(&mut self, i: u64) -> Result<IndexEntry, Error> /* {{{ */ {
 		let pos = self.index_start_position() + (i * Self::INDEX_ENTRY_SIZE as u64);
 		self.file.seek(SeekFrom::Start(pos)).await?;
@@ -294,7 +294,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	/// Looks up a single value by key.  Will attempt to cache data positions in the backing file
 	/// to minimize disk seeking.  Returns [Error::NotFound] when `key` does not exist in the
 	/// Store.
-	#[instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display()))]
+	#[cfg_attr(feature = "full-instrumentation", instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display())))]
 	#[inline]
 	pub async fn get(&mut self, key: u64) -> Result<T, Error> /* {{{ */ {
 		let position = match self.index_cache.get(&key) {
